@@ -1,20 +1,22 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "pc"
-#define HOST_OS "bsdi4.0"
+#define HOST_OS "bsdi4.0.1"
 #define HOST_OS_NAME "bsdi4"
-#define HOST_OS_VERSION "4.0"
+#define HOST_OS_VERSION "4.0.1"
 #define HOST_ARCH "i386"
 #define HOST_NAME "cricket.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Mar 18 01:20:05 EST 1999"
+#define CONFIG_DATE "Wed Jan 12 13:51:29 EST 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.1s7"
+#define VERSION "6.0.3s3"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.1s7"
+#define VERSION "6.0.3s3"
 #define DEBUG 1
+#define HOST_HEADER_VERSION "4.0.1"
 #define HAVE_LIBRPC 1
 #define HAVE_LIBRPCSVC 1
+#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
@@ -29,6 +31,7 @@
 #define HAVE_GETDOMAINNAME 1
 #define HAVE_GETDTABLESIZE 1
 #define HAVE_GETHOSTNAME 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
@@ -46,6 +49,7 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
+#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -63,6 +67,7 @@
 #define HAVE_UNAME 1
 #define HAVE_UNMOUNT 1
 #define HAVE_VFORK 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -163,6 +168,8 @@
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_IFADDRS_H 1
+#define HAVE_IRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -218,12 +225,14 @@
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
+#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
@@ -238,6 +247,7 @@
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
 #define HAVE_MAP_HESIOD 1
@@ -282,6 +292,7 @@
 #define MNTTAB_TYPE_TFS "tfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_AUTOMNTFS 0x200000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
